---

name: Documentation Improvement
about: Report wrong or missing documentation
title: "DOC:"
labels: "Docs, Needs Triage"

---

#### Location of the documentation

[this should provide the location of the documentation, e.g. "pyxel.models.photon_generation.load_image" or the URL of the documentation, e.g. "https://esa.gitlab.io/pyxel/doc/models.html#module-pyxel.models.photon_generation"]

**Note**: You can check the latest versions of the docs on `master` [here](https://esa.gitlab.io/pyxel/doc/).

#### Documentation problem

[this should provide a description of what documentation you believe needs to be fixed/improved]

#### Suggested fix for documentation

[this should explain the suggested fix and **why** it's better than the existing documentation]